summaryrefslogtreecommitdiff
path: root/src/diff_xdiff.h
diff options
context:
space:
mode:
authorEdward Thomson <ethomson@edwardthomson.com>2015-09-11 08:37:12 -0400
committerEdward Thomson <ethomson@github.com>2016-05-26 13:01:04 -0500
commit804d5fe9f59f4d8548da9f650bc43050951f26d7 (patch)
treedcb30d7b1721021d14731eb67a615d9c829f8833 /src/diff_xdiff.h
parent8d2eef27ffae3fe9cfbaa0c0c16655598b5b1d6b (diff)
downloadlibgit2-804d5fe9f59f4d8548da9f650bc43050951f26d7.tar.gz
patch: abstract patches into diff'ed and parsed
Patches can now come from a variety of sources - either internally generated (from diffing two commits) or as the results of parsing some external data.
Diffstat (limited to 'src/diff_xdiff.h')
-rw-r--r--src/diff_xdiff.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/diff_xdiff.h b/src/diff_xdiff.h
index 98e11b2cb..e1c58a229 100644
--- a/src/diff_xdiff.h
+++ b/src/diff_xdiff.h
@@ -8,20 +8,20 @@
#define INCLUDE_diff_xdiff_h__
#include "diff.h"
-#include "diff_patch.h"
#include "xdiff/xdiff.h"
+#include "patch_diff.h"
/* xdiff cannot cope with large files. these files should not be passed to
* xdiff. callers should treat these large files as binary.
*/
#define GIT_XDIFF_MAX_SIZE (1024LL * 1024 * 1023)
/* A git_xdiff_output is a git_diff_output with extra fields necessary
* to use libxdiff. Calling git_xdiff_init() will set the diff_cb field
* of the output to use xdiff to generate the diffs.
*/
typedef struct {
- git_diff_output output;
+ git_patch_diff_output output;
xdemitconf_t config;
xpparam_t params;
@@ -8,20 +8,20 @@
*/
#define GIT_XDIFF_MAX_SIZE (1024LL * 1024 * 1023)
-/* A git_xdiff_output is a git_diff_output with extra fields necessary
+/* A git_xdiff_output is a git_patch_diff_output with extra fields necessary
* to use libxdiff. Calling git_xdiff_init() will set the diff_cb field
* of the output to use xdiff to generate the diffs.